import { Command as $Command } from "@smithy/smithy-client";
import { MetadataBearer as __MetadataBearer } from "@smithy/types";
import { CodePipelineClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../CodePipelineClient";
import { PutApprovalResultInput, PutApprovalResultOutput } from "../models/models_0";
/**
 * @public
 */
export type { __MetadataBearer };
export { $Command };
/**
 * @public
 *
 * The input for {@link PutApprovalResultCommand}.
 */
export interface PutApprovalResultCommandInput extends PutApprovalResultInput {
}
/**
 * @public
 *
 * The output of {@link PutApprovalResultCommand}.
 */
export interface PutApprovalResultCommandOutput extends PutApprovalResultOutput, __MetadataBearer {
}
declare const PutApprovalResultCommand_base: {
    new (input: PutApprovalResultCommandInput): import("@smithy/smithy-client").CommandImpl<PutApprovalResultCommandInput, PutApprovalResultCommandOutput, CodePipelineClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    new (__0_0: PutApprovalResultCommandInput): import("@smithy/smithy-client").CommandImpl<PutApprovalResultCommandInput, PutApprovalResultCommandOutput, CodePipelineClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes>;
    getEndpointParameterInstructions(): import("@smithy/middleware-endpoint").EndpointParameterInstructions;
};
/**
 * <p>Provides the response to a manual approval request to CodePipeline. Valid
 *             responses include Approved and Rejected.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { CodePipelineClient, PutApprovalResultCommand } from "@aws-sdk/client-codepipeline"; // ES Modules import
 * // const { CodePipelineClient, PutApprovalResultCommand } = require("@aws-sdk/client-codepipeline"); // CommonJS import
 * const client = new CodePipelineClient(config);
 * const input = { // PutApprovalResultInput
 *   pipelineName: "STRING_VALUE", // required
 *   stageName: "STRING_VALUE", // required
 *   actionName: "STRING_VALUE", // required
 *   result: { // ApprovalResult
 *     summary: "STRING_VALUE", // required
 *     status: "Approved" || "Rejected", // required
 *   },
 *   token: "STRING_VALUE", // required
 * };
 * const command = new PutApprovalResultCommand(input);
 * const response = await client.send(command);
 * // { // PutApprovalResultOutput
 * //   approvedAt: new Date("TIMESTAMP"),
 * // };
 *
 * ```
 *
 * @param PutApprovalResultCommandInput - {@link PutApprovalResultCommandInput}
 * @returns {@link PutApprovalResultCommandOutput}
 * @see {@link PutApprovalResultCommandInput} for command's `input` shape.
 * @see {@link PutApprovalResultCommandOutput} for command's `response` shape.
 * @see {@link CodePipelineClientResolvedConfig | config} for CodePipelineClient's `config` shape.
 *
 * @throws {@link ActionNotFoundException} (client fault)
 *  <p>The specified action cannot be found.</p>
 *
 * @throws {@link ApprovalAlreadyCompletedException} (client fault)
 *  <p>The approval action has already been approved or rejected.</p>
 *
 * @throws {@link InvalidApprovalTokenException} (client fault)
 *  <p>The approval request already received a response or has expired.</p>
 *
 * @throws {@link PipelineNotFoundException} (client fault)
 *  <p>The pipeline was specified in an invalid format or cannot be found.</p>
 *
 * @throws {@link StageNotFoundException} (client fault)
 *  <p>The stage was specified in an invalid format or cannot be found.</p>
 *
 * @throws {@link ValidationException} (client fault)
 *  <p>The validation was specified in an invalid format.</p>
 *
 * @throws {@link CodePipelineServiceException}
 * <p>Base exception class for all service exceptions from CodePipeline service.</p>
 *
 * @public
 */
export declare class PutApprovalResultCommand extends PutApprovalResultCommand_base {
}
